@@ -74,17 +74,9 @@
 #include "MagickCore/string-private.h"
 #include "MagickCore/version.h"
 #include "MagickCore/version-private.h"
-#undef HAVE_DISTRIBUTE_CACHE
+#undef MAGICKCORE_HAVE_DISTRIBUTE_CACHE
 #if defined(MAGICKCORE_DPC_SUPPORT)
-#if defined(MAGICKCORE_WINDOWS_SUPPORT) && !defined(__CYGWIN__)
-#define CLOSE_SOCKET(socket) (void) closesocket(socket)
-#define HANDLER_RETURN_TYPE DWORD WINAPI
-#define HANDLER_RETURN_VALUE 0
-#define SOCKET_TYPE SOCKET
-#define LENGTH_TYPE int
-#define HAVE_DISTRIBUTE_CACHE 1
-#define HAVE_WINSOCK2 1
-#elif defined(MAGICKCORE_HAVE_SOCKET) && defined(MAGICKCORE_THREAD_SUPPORT)
+#if defined(MAGICKCORE_HAVE_SOCKET) && defined(MAGICKCORE_THREAD_SUPPORT)
 #include <netinet/in.h>
 #include <netdb.h>
 #include <sys/socket.h>
@@ -94,7 +86,15 @@
 #define HANDLER_RETURN_VALUE (void *) NULL
 #define SOCKET_TYPE int
 #define LENGTH_TYPE size_t
-#define HAVE_DISTRIBUTE_CACHE 1
+#define MAGICKCORE_HAVE_DISTRIBUTE_CACHE 1
+#elif defined(MAGICKCORE_WINDOWS_SUPPORT) && !defined(__CYGWIN__)
+#define CLOSE_SOCKET(socket) (void) closesocket(socket)
+#define HANDLER_RETURN_TYPE DWORD WINAPI
+#define HANDLER_RETURN_VALUE 0
+#define SOCKET_TYPE SOCKET
+#define LENGTH_TYPE int
+#define MAGICKCORE_HAVE_DISTRIBUTE_CACHE 1
+#define MAGICKCORE_HAVE_WINSOCK2 1
 #endif
 #else
 #ifdef __VMS
@@ -125,7 +125,7 @@
 /*
   Static declarations.
 */
-#ifdef HAVE_WINSOCK2
+#ifdef MAGICKCORE_HAVE_WINSOCK2
 static SemaphoreInfo
   *winsock2_semaphore = (SemaphoreInfo *) NULL;
 
@@ -165,7 +165,7 @@ static inline MagickOffsetType dpc_read(int file,const MagickSizeType length,
   ssize_t
     count;
 
-#if !defined(HAVE_DISTRIBUTE_CACHE)
+#if !defined(MAGICKCORE_HAVE_DISTRIBUTE_CACHE)
   magick_unreferenced(file);
   magick_unreferenced(message);
 #endif
@@ -184,7 +184,7 @@ static inline MagickOffsetType dpc_read(int file,const MagickSizeType length,
   return(i);
 }
 
-#if defined(HAVE_WINSOCK2)
+#if defined(MAGICKCORE_HAVE_WINSOCK2)
 static void InitializeWinsock2(MagickBooleanType use_lock)
 {
   if (use_lock)
@@ -207,7 +207,7 @@ static void InitializeWinsock2(MagickBooleanType use_lock)
 static int ConnectPixelCacheServer(const char *hostname,const int port,
   size_t *session_key,ExceptionInfo *exception)
 {
-#if defined(HAVE_DISTRIBUTE_CACHE)
+#if defined(MAGICKCORE_HAVE_DISTRIBUTE_CACHE)
   char
     service[MagickPathExtent],
     *shared_secret;
@@ -232,7 +232,7 @@ static int ConnectPixelCacheServer(const char *hostname,const int port,
     Connect to distributed pixel cache and get session key.
   */
   *session_key=0;
-#if defined(HAVE_WINSOCK2)
+#if defined(MAGICKCORE_HAVE_WINSOCK2)
   InitializeWinsock2(MagickTrue);
 #endif
   (void) memset(&hint,0,sizeof(hint));
@@ -466,7 +466,7 @@ static inline MagickOffsetType dpc_send(int file,const MagickSizeType length,
     count,
     i;
 
-#if !defined(HAVE_DISTRIBUTE_CACHE)
+#if !defined(MAGICKCORE_HAVE_DISTRIBUTE_CACHE)
   magick_unreferenced(file);
   magick_unreferenced(message);
 #endif
@@ -489,7 +489,7 @@ static inline MagickOffsetType dpc_send(int file,const MagickSizeType length,
   return(i);
 }
 
-#if !defined(HAVE_DISTRIBUTE_CACHE)
+#if !defined(MAGICKCORE_HAVE_DISTRIBUTE_CACHE)
 MagickExport void DistributePixelCacheServer(const int port,
   ExceptionInfo *exception)
 {
@@ -965,7 +965,7 @@ MagickExport void DistributePixelCacheServer(const int port,
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
   magick_unreferenced(exception);
-#if defined(HAVE_WINSOCK2)
+#if defined(MAGICKCORE_HAVE_WINSOCK2)
   InitializeWinsock2(MagickFalse);
 #endif
   (void) memset(&hint,0,sizeof(hint));
@@ -1053,7 +1053,7 @@ MagickExport void DistributePixelCacheServer(const int port,
 */
 MagickPrivate void DistributeCacheTerminus(void)
 {
-#ifdef HAVE_WINSOCK2
+#ifdef MAGICKCORE_HAVE_WINSOCK2
   if (winsock2_semaphore == (SemaphoreInfo *) NULL)
     ActivateSemaphoreInfo(&winsock2_semaphore);
   LockSemaphoreInfo(winsock2_semaphore);
